Package: cooccure
Title: Co-Occurrence Network Construction and Manipulation
Version: 0.1.1
Authors@R: c(
    person("Mohammed", "Saqr", email = "saqr@saqr.me",
           role = c("aut", "cre", "cph")),
    person("Sonsoles", "López-Pernas", email = "sonsoles.lopez@uef.fi",
           role = c("aut", "cph")),
    person("Kamila", "Misiejuk", role = c("aut", "cph")))
Description: Constructs co-occurrence networks from several types of input
    data, such as delimited fields, long/bipartite tables, binary
    matrices, or wide sequences. Returns tidy edge data frames and
    supports optional scaling, splitting into several networks,
    thresholding, and subsetting. Provides eight similarity measures,
    including Jaccard, cosine, and association strength. Supports export
    to several network and file formats. Network construction and
    analysis methods follow Saqr, Lopez-Pernas, Conde, and
    Hernandez-Garcia (2024, <doi:10.1007/978-3-031-54464-4_15>).
License: MIT + file LICENSE
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
Imports: graphics, Matrix, methods, stats, utils
Suggests: igraph, cograph, Nestimate, tidygraph, testthat (>= 3.0.0),
        knitr, rmarkdown, shiny, DT
Config/testthat/edition: 3
VignetteBuilder: knitr
Depends: R (>= 3.5.0)
URL: https://github.com/mohsaqr/cooccure
BugReports: https://github.com/mohsaqr/cooccure/issues
NeedsCompilation: no
Packaged: 2026-04-22 20:37:56 UTC; mohammedsaqr
Author: Mohammed Saqr [aut, cre, cph],
  Sonsoles López-Pernas [aut, cph],
  Kamila Misiejuk [aut, cph]
Maintainer: Mohammed Saqr <saqr@saqr.me>
Repository: CRAN
Date/Publication: 2026-04-24 20:20:10 UTC
Built: R 4.5.2; ; 2026-04-24 23:25:04 UTC; unix
