% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/converters.R
\name{as_netobject}
\alias{as_netobject}
\alias{as_netobject.cooccurrence}
\title{Convert to Nestimate netobject}
\usage{
as_netobject(x, ...)

\method{as_netobject}{cooccurrence}(x, ...)
}
\arguments{
\item{x}{A \code{cooccurrence} data frame.}

\item{...}{Ignored.}
}
\value{
A \code{netobject} with class \code{c("netobject", "cograph_network")}.
}
\description{
Creates a \code{netobject} from a \code{cooccurrence} edge list,
compatible with \code{Nestimate::centrality()},
\code{Nestimate::bootstrap_network()}, etc.
}
\examples{
res <- cooccurrence(list(c("A","B","C"), c("B","C"), c("A","C")))
if (requireNamespace("Nestimate", quietly = TRUE)) {
  net <- as_netobject(res)
  net$n_nodes
}
}
