% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/converters.R
\name{as_cograph}
\alias{as_cograph}
\alias{as_cograph.cooccurrence}
\title{Convert to cograph network}
\usage{
as_cograph(x, ...)

\method{as_cograph}{cooccurrence}(x, ...)
}
\arguments{
\item{x}{A \code{cooccurrence} data frame.}

\item{...}{Ignored.}
}
\value{
A \code{cograph_network} object.
}
\description{
Creates a \code{cograph_network} object from a \code{cooccurrence}
edge list, compatible with \code{cograph::splot()} and other cograph
functions.
}
\examples{
res <- cooccurrence(list(c("A","B","C"), c("B","C"), c("A","C")))
if (requireNamespace("cograph", quietly = TRUE)) {
  net <- as_cograph(res)
  net$n_nodes
}
}
