% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/converters.R
\name{as_igraph}
\alias{as_igraph}
\alias{as_igraph.cooccurrence}
\title{Convert to igraph}
\usage{
as_igraph(x, ...)

\method{as_igraph}{cooccurrence}(x, ...)
}
\arguments{
\item{x}{A \code{cooccurrence} data frame.}

\item{...}{Passed to \code{igraph::graph_from_data_frame}.}
}
\value{
An \code{igraph} object.
}
\description{
Creates an undirected, weighted \code{igraph} graph from a
\code{cooccurrence} edge list.
}
\examples{
res <- cooccurrence(list(c("A","B","C"), c("B","C"), c("A","C")))
if (requireNamespace("igraph", quietly = TRUE)) {
  g <- as_igraph(res)
  igraph::vcount(g)
}
}
